import { AxiosInstance } from "axios";
import { RequestHandler } from "express";
export declare enum Methods {
    POST = "POST",
    PUT = "PUT",
    DELETE = "DELETE",
    PATCH = "PATCH",
    GET = "GET"
}
export type RoutePermission = {
    method: Methods;
    path: string;
};
export type Scopes = {
    [domain: string]: RoutePermission[];
};
export type JwtPayload = {
    service_from: string;
    service_to: string;
    scope: RoutePermission[];
};
export type ServiceMeta = {
    clientPrivateKey: string;
    portalPublicKey: string;
    serviceId: string;
};
export type PortalOptions = {
    hostname?: string;
    portalHost?: string;
    metaFilePath?: string;
    clientId: string;
    clientSecret: string;
    label?: string;
    description?: string;
};
export declare class CrysteamPortal {
    private _serviceMeta?;
    private readonly _tokenCache;
    private readonly _axios;
    private readonly _hostname?;
    private readonly _portalHost;
    private readonly _metaFilePath;
    private readonly _secretKey;
    constructor(options: PortalOptions);
    private _initialize;
    private sign;
    private buildSignedPayload;
    private generateRsaKeyPair;
    private saveMetaToFile;
    private loadMetaFromFile;
    getScopes(): Promise<Scopes>;
    registerService(label: string, description?: string): Promise<string | undefined>;
    generateAccessToken(serviceFrom: string, scope: RoutePermission[]): Promise<string>;
    getServiceScopesFor(domain: string): Promise<RoutePermission[]>;
    isScopeAllowed(scopes: RoutePermission[], permission: RoutePermission): boolean;
    isScopeAllowed(domain: string, permission: RoutePermission): Promise<boolean>;
    createHttpClientFor(serviceFrom: string, scope: RoutePermission[]): AxiosInstance;
    verifyApiKey(): RequestHandler;
}
